require.config({
    baseUrl: 'js',
    paths: {
        components: '../bower_components'
    }
});

/**
 * Require files in proper order. Today I would use Browserify for that purpose and module loading
 */
require(['components/howler/howler.min', 'components/angular/angular.min', 'components/mobile-detect/mobile-detect.min'], function (howler, b, mb) {

    // detect
    window.MobileDetect = new mb(window.navigator.userAgent);

    require(['components/angular-route/angular-route.min'], function () {
        //lod main file and bootstrap app
        require(['main.min'], function () {

            var progress = 0;
            var ui_div = document.getElementById('loaded');

            /**
             *
             * @type {Function|string}
             *
             * Parse location string to get language version of the app
             * This is due to different domains and one codebase - we do not hosting environment
             *
             */
            var langStringToEval = ( window.location.search.indexOf('lang') > -1 ) ? window.location.search : window.location.pathname;
            var lang = 'de';
            if (langStringToEval.indexOf("/ch_fr") > -1 || langStringToEval.indexOf('lang=fr') > -1) {
                lang = "fr";
            } else if (langStringToEval.indexOf("-en") > -1 || langStringToEval.indexOf('lang=en') > -1) {
                lang = "en";
            }

            //get spritesheet url - retrieve it from css as spritesheet name is dynamically generated with Compass
            var spritesheet_url = $(document.getElementsByClassName('preloader-class')).css('backgroundImage').replace(/^url\(["']?/, '').replace(/["']?\)$/, '');

            function handleProgress(event){
                progress = event.progress;
                ui_div.innerText = parseInt(progress * 100)+ "%";
            }

            //create manifest and load queue of elements (sprite sheets, translations etc.). Then bootstrap app.
            var queue = new createjs.LoadQueue();
            var manifestArray = [
                {id: "spritesheet", src: spritesheet_url },
                {id: "translations", src:"samsung-translations.html"},
                {id: "playlist", src:"http://yourheartbeat.ch/api/get-playlist-v2" },
                {id: "playbacks", src:"http://yourheartbeat.ch/api/get-playback-count" },
                {id: "about", src: "partials/about.html"},
                {id: "form", src: "partials/form.html"},
                {id: "remix", src: "partials/remix.html"},
                {id: "presets", src: "partials/presets.html"},
                {id: "remixcreated", src: "partials/remixcreated.html"},
                {id: "remixgif", src: "partials/remixGif.html"},
                {id: "soundDeck", src: "partials/soundsDeck.html"},
                {id: "james", src: "img/bg/bg_01.jpg"},
                {id: "samsung", src: "img/bg/samsung_galaxy.png"},
                {id: "heart", src: "img/heart.png"},
                {id: "heart_mobile", src: "img/heart_mobile.png"},
                {id: "mobius_loop", src: "img/mobius_loop.png"},
                {id: "center_phone", src: "img/center_phone.png"}

            ];
            queue.on("complete", handleComplete, this);
            queue.on("progress", handleProgress, this);
            queue.loadManifest(manifestArray); //trigger loading process

            function handleComplete() {
                /**
                 * Parse loaded json files
                 */
                var translations = JSON.parse( queue.getResult("translations") );
                var playlist = JSON.parse( queue.getResult("playlist") );
                var playbacks = JSON.parse( queue.getResult("playbacks") );

                //remove reploader node
                ui_div.parentNode.parentNode.parentNode.removeChild(ui_div.parentNode.parentNode);

                //create angular Application
                samsungApp = angular.module('samsungApp', ['Services', 'Controllers', 'Directives', 'Animations', 'ngSanitize', 'ngRoute']);

                /**
                 * default config. Previously we were planning to use Twig templating engine, hence $interpolateProvider
                 * to change default angular tags {{ }}
                 */
                samsungApp.config(['$interpolateProvider', '$routeProvider', '$locationProvider', function ($interpolateProvider, $routeProvider, $locationProvider) {
                    $locationProvider.html5Mode(false);
                }]);

                //set constants for use inside different controllers
                samsungApp.constant('Events', Events);
                samsungApp.constant('translations', translations);
                samsungApp.constant('language', lang);
                samsungApp.constant('playlist', playlist);
                samsungApp.constant('playbacksCount', playbacks);

                //bootstrap application
                angular.bootstrap('body', ['samsungApp']);

            }
        });
    });
});

var samsungApp;